@@ -15,7 +15,7 @@ attributes defined in this subclass.
 # Copyright (c) 2001 - 2015 The SCons Foundation
 from __future__ import division
 
-__revision__ = "QMTest/TestSCons.py rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog"
+__revision__ = "QMTest/TestSCons.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
 
 import os
 import re
@@ -34,7 +34,7 @@ from TestCmd import PIPE
 # here provides some independent verification that what we packaged
 # conforms to what we expect.
 
-default_version = '2.4.0'
+default_version = '2.4.1'
 
 python_version_unsupported = (2, 3, 0)
 python_version_deprecated = (2, 7, 0)
@@ -43,7 +43,7 @@ python_version_deprecated = (2, 7, 0)
 # line must remain "__ VERSION __" (without the spaces) so the built
 # version in build/QMTest/TestSCons.py contains the actual version
 # string of the packages that have been built.
-SConsVersion = '2.4.0'
+SConsVersion = '2.4.1'
 if SConsVersion == '__' + 'VERSION' + '__':
     SConsVersion = default_version
 
@@ -714,6 +714,9 @@ class TestSCons(TestCommon):
                 home = '/System/Library/Frameworks/JavaVM.framework/Home'
             else:
                 home = '/System/Library/Frameworks/JavaVM.framework/Versions/%s/Home' % version
+                if not os.path.exists(home):
+                    # This works on OSX 10.10
+                    home = '/System/Library/Frameworks/JavaVM.framework/Versions/Current/'
         else:
             jar = self.java_where_jar(version)
             home = os.path.normpath('%s/..'%jar)
