@@ -1,6 +1,6 @@
 #!/usr/bin/env sh
 #
-# Simple hack script to restore __revision__, __COPYRIGHT_, 2.4.0
+# Simple hack script to restore __revision__, __COPYRIGHT_, 2.4.1
 # and other similar variables to what gets checked in to source.  This
 # comes in handy when people send in diffs based on the released source.
 #
@@ -24,7 +24,7 @@ for i in `find $DIRS -name '*.py'`; do
     ed $i <<EOF
 g/Copyright (c) 2001.*SCons Foundation/s//Copyright (c) 2001 - 2015 The SCons Foundation/p
 w
-/^__revision__ = /s/= .*/= "bin/restore.sh rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog"/p
+/^__revision__ = /s/= .*/= "bin/restore.sh rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"/p
 w
 q
 EOF
@@ -35,7 +35,7 @@ for i in `find $DIRS -name 'scons.bat'`; do
     ed $i <<EOF
 g/Copyright (c) 2001.*SCons Foundation/s//Copyright (c) 2001 - 2015 The SCons Foundation/p
 w
-/^@REM src\/script\/scons.bat/s/@REM .* knight/@REM bin/restore.sh rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog/p
+/^@REM src\/script\/scons.bat/s/@REM .* knight/@REM bin/restore.sh rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog/p
 w
 q
 EOF
@@ -44,13 +44,13 @@ done
 for i in `find $DIRS -name '__init__.py' -o -name 'scons.py' -o -name 'sconsign.py'`; do
     header $i
     ed $i <<EOF
-/^__version__ = /s/= .*/= "2.4.0"/p
+/^__version__ = /s/= .*/= "2.4.1"/p
 w
-/^__build__ = /s/= .*/= "rel_2.4.0:3365:9259ea1c13d7"/p
+/^__build__ = /s/= .*/= "rel_2.4.1:3453:73fefd3ea0b0"/p
 w
-/^__buildsys__ = /s/= .*/= "hpmicrodog"/p
+/^__buildsys__ = /s/= .*/= "ubuntu1404-32bit"/p
 w
-/^__date__ = /s/= .*/= "2015/09/21 14:03:43"/p
+/^__date__ = /s/= .*/= "2015/11/09 03:25:05"/p
 w
 /^__developer__ = /s/= .*/= "bdbaddog"/p
 w
@@ -61,7 +61,7 @@ done
 for i in `find $DIRS -name 'setup.py'`; do
     header $i
     ed $i <<EOF
-/^ *version = /s/= .*/= "2.4.0",/p
+/^ *version = /s/= .*/= "2.4.1",/p
 w
 q
 EOF
@@ -72,9 +72,9 @@ for i in `find $DIRS -name '*.txt'`; do
     ed $i <<EOF
 g/Copyright (c) 2001.*SCons Foundation/s//Copyright (c) 2001 - 2015 The SCons Foundation/p
 w
-/# [^ ]* 0.96.[CD][0-9]* [0-9\/]* [0-9:]* knight$/s/.*/# bin/restore.sh rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog/p
+/# [^ ]* 0.96.[CD][0-9]* [0-9\/]* [0-9:]* knight$/s/.*/# bin/restore.sh rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog/p
 w
-/Version [0-9][0-9]*\.[0-9][0-9]*/s//Version 2.4.0/p
+/Version [0-9][0-9]*\.[0-9][0-9]*/s//Version 2.4.1/p
 w
 q
 EOF
